CloneDigger Report

Source files: 3

Click here to show/hide file names

Source files:
optimize/customcg.py,
optimize/optimize.py,
optimize/__init__.py

Clones detected: 3

15 of 384 lines are duplicates (3.91%)

Parameters
clustering_threshold = 10
distance_threshold = 5
size_threshold = 5
hashing_depth = 1
clusterize_using_hash = False
clusterize_using_dcup = False

Time elapsed
Construction of AST : 0.09 seconds
Building statement hash : 0.00 seconds
Building patterns : 0.07 seconds
Marking similar statements : 0.08 seconds
Finding similar sequences of statements : 0.01 seconds
Refining candidates : 0.00 seconds
Total time: 0.26
Started at: Mon Aug 1 06:56:33 2016
Finished at: Mon Aug 1 06:56:34 2016

Clone # 1
Distance between two fragments = 2
Clone size = 5

Source file "optimize/optimize.py" The first line is 292 |  | Source file "optimize/optimize.py" The first line is 222
if counter < maxiter: solution.success = True else: solution.success = False solution.message = 'Maximum iterations exceeded' |  | if i < max_outer_iter: solution.success = True else: solution.success = False solution.message = 'Maximum iterations exceeded'
return solution |  | return solution

Clone # 2
Distance between two fragments = 2
Clone size = 5

Source file "optimize/optimize.py" The first line is 292 |  | Source file "optimize/customcg.py" The first line is 127
if counter < maxiter: solution.success = True else: solution.success = False solution.message = 'Maximum iterations exceeded' |  | if step < maxiters: solution.success = True else: solution.success = False solution.message = 'Maximum iterations exceeded'
return solution |  | return solution

Clone # 3
Distance between two fragments = 2
Clone size = 5

Source file "optimize/optimize.py" The first line is 222 |  | Source file "optimize/customcg.py" The first line is 127
if i < max_outer_iter: solution.success = True else: solution.success = False solution.message = 'Maximum iterations exceeded' |  | if step < maxiters: solution.success = True else: solution.success = False solution.message = 'Maximum iterations exceeded'
return solution |  | return solution

Clone Digger is aimed to find software clones in Python and Java programs. It is provided under the GPL license and can be downloaded from the site http://clonedigger.sourceforge.net